
# AllSpeak

[![Build Status](https://travis-ci.org/lucuma/allspeak.png)](https://travis-ci.org/lucuma/allspeak)

AllSpeak is a pythonic (yet ironically inspired by Rails) i18n/l10n solution for humans
doing WSGI-based web applications.  It's flexible, easy to use and
—unlike gettext— independent of any external compilation tool.

Powered by the awesome Babel and pytz libraries for the l10n part.

The library is compatible with Werkzeug, Webob and Django request objects, so you can use it with pretty much any WSGI-based framework.

See the documentation online at http://lucuma.github.com/allspeak

---------------------------------------

[MIT License](http://www.opensource.org/licenses/mit-license.php).

© 2012 [Lúcuma labs](http://lucumalabs.com).
